## Installation

Use pip:

```$ pip install hkavr```
  
## Usage

To create a device:
```
import hkavr
hk = hkavr.HkAVR("192.168.0.250", "Name (Optional)")
```

## License
MIT

## Author
@Devqon: https://github.com/Devqon